@@ -7,41 +7,33 @@ from tqdm import tqdm
 from textgrid_tools.grids.marks_exporting import get_marks_txt
 from textgrid_tools_cli.globals import ExecutionResult
 from textgrid_tools_cli.helper import (add_directory_argument, add_encoding_argument,
-                                       add_overwrite_argument, get_grid_files,
-                                       parse_non_empty_or_whitespace, parse_path, try_load_grid)
+                                       get_grid_files, parse_non_empty_or_whitespace,
+                                       parse_txt_path, try_load_grid)
 from textgrid_tools_cli.logging_configuration import get_file_logger, init_and_get_console_logger
-from textgrid_tools_cli.validation import FileAlreadyExistsError
 
 
 def get_marks_exporting_parser(parser: ArgumentParser):
   parser.description = "This command exports all marks on a tier of all grids into one text file."
   add_directory_argument(parser)
-  parser.add_argument("tier", type=parse_non_empty_or_whitespace,
+  parser.add_argument("tier", type=parse_non_empty_or_whitespace, metavar="TIER",
                       help="tier containing the intervals that should be exported")
-  parser.add_argument("output", type=parse_path, metavar="output",
+  parser.add_argument("output", type=parse_txt_path, metavar="OUTPUT",
                       help="path to output the marks (*.txt)")
-  parser.add_argument("--sep", type=str,
+  parser.add_argument("--sep", type=str, metavar="SEP",
                       help="separator for intervals in output", default="|")
-  add_encoding_argument(parser, "encoding of input grid files and output text files")
-  add_overwrite_argument(parser)
-  return app_plot_interval_durations
+  add_encoding_argument(parser, "encoding of input grid files and OUTPUT text file")
+  return export_marks_ns
 
 
-def app_plot_interval_durations(ns: Namespace) -> ExecutionResult:
+def export_marks_ns(ns: Namespace) -> ExecutionResult:
   logger = init_and_get_console_logger(__name__)
   flogger = get_file_logger()
 
   grid_files = get_grid_files(ns.directory)
 
-  if ns.output.suffix.lower() not in {".txt"}:
-    logger.error("Only .txt outputs are supported!")
-    return False, False
-
-  if not ns.overwrite and (error := FileAlreadyExistsError.validate(ns.output)):
-    logger.error(error.default_message)
-    return False, False
-
   grids: List[TextGrid] = []
+  # TODO all successful false on skipped files
+  all_successful = True
   for file_nr, (file_stem, rel_path) in enumerate(tqdm(grid_files.items()), start=1):
     flogger.info(f"Processing {file_stem}")
     grid_file_in_abs = ns.directory / rel_path
@@ -51,6 +43,7 @@ def app_plot_interval_durations(ns: Namespace) -> ExecutionResult:
       flogger.debug(error.exception)
       flogger.error(error.default_message)
       flogger.info("Skipped.")
+      all_successful = False
       continue
     assert grid is not None
 
@@ -66,6 +59,6 @@ def app_plot_interval_durations(ns: Namespace) -> ExecutionResult:
 
   ns.output.parent.mkdir(parents=True, exist_ok=True)
   ns.output.write_text(txt, ns.encoding)
-  logger.info(f"Exported text to: {ns.output}")
+  logger.info(f"Exported text from {len(grids)} grid(s) to: \"{ns.output.absolute()}\".")
 
-  return True, False
+  return all_successful, True
